pub struct FlowConfig {
pub from: String,
pub to: String,
pub topics: Selectors,
pub groups: Selectors,
pub naming: NamingPolicy,
pub delivery: Delivery,
}Expand description
A directional replication flow from one cluster to another.
Fields
from: StringSource cluster alias.
to: StringTarget cluster alias.
topics: SelectorsTopic selector (include / exclude glob patterns).
groups: SelectorsConsumer-group selector (include / exclude glob patterns).
naming: NamingPolicyHow replicated topics are named on the target cluster.
delivery: DeliveryDelivery guarantee.