Module source

Module source 

Source side: a consumer on the source cluster that emits ReplicatedRecords and snapshots all partition positions as a SourceOffset.

Structs

SourceConsumer
A Source implementation backed by a Kafka consumer on the source cluster.