Source side: a consumer on the source cluster that emits ReplicatedRecords
and snapshots all partition positions as a SourceOffset.
Structs
- Source
Consumer - A
Sourceimplementation backed by a Kafka consumer on the source cluster.